BusMap.Embed = function(opts) {
    var embedVars = {};
    var that = this.Embed;
    that.opts = opts;

    /* Constructor - initialize the embed form */
    function init() {
        bindEventHandlers();
        populateOptions();
    }
    var updateEmbedCode = function() {
        // Grab HTML representation of preview; trim whitespace.
        var code = $("#embed-preview").html().trim();
        // Remove empty style attribute. OCD is good!
        code = code.replace(" style=''","");
        code = code.replace(' style=""',"");
        // Put it in the textarea.
        $("#embed-code").html(code);
    }

    var populateOptions = function() {
        var stops = window._busmap.stops;
        stops = Object.keys(stops).map(function(i){return stops[i]});
        stops = stops.sort(function(a,b){
            if (a.title > b.title) return 1;
            else if (a.title < b.title) return -1;
            return 0;
        });
        for (id in stops) {
            var s = stops[id];
            var opt = $('<option value="' + s.id + '">' + s.title + '</option>');
            opt.appendTo("#embed-stop");
        }
        if ($("#embed-stop option").length > 1 && !$("#embed-stop").val()) {
            // We have stops.
            if (window._busmap.selectedStop) {
                // Select the last one clicked if available.
                $("#embed-stop").val(window._busmap.selectedStop);
            } else {
                // Select the first one.
                $("#embed-stop option:nth-child(2)").prop('selected', true);
            }
            $("#embed-stop").change(); // fire event to handle the change
        }
    }

    var updateEmbedUrl = function() {
        var newUrl = opts.baseUrl;
        if (embedVars.mode) newUrl += embedVars.mode;
        if (embedVars.stop) {
            if (embedVars.popup) newUrl += "#S" + embedVars.stop;
            else newUrl += "#s" + embedVars.stop;
        }
        $("#embed-preview iframe").get(0).src = newUrl;
    }

    var bindEventHandlers = function() {
        // OnChange event handlers for Embed Options form
        $("#embed-height").on('change', function() {
            if ($(this).val() != "") {
                $("#embed-preview iframe").attr('height', $(this).val() + "px");
            } else {
                $("#embed-preview iframe").removeAttr('height');
            }
        });
        $("#embed-width").on('change', function() {
            if ($(this).val() != "") {
                $("#embed-preview iframe").attr('width', $(this).val() + "px");
            } else {
                $("#embed-preview iframe").removeAttr('width');
            }
        });
        $("#embed-responsive").on('change', function() {
            if ($(this).prop("checked")) {
                $("#embed-preview iframe").css('max-width', '100%');
            } else {
                $("#embed-preview iframe").css('max-width', '');
            }
        });
        $("#embed-mode").on('change', function() {
            embedVars['mode'] = $(this).val();
            updateEmbedUrl();
            if ($(this).val() == "m" || $(this).val() == "c") {
                $("label[for=embed-popup]").show();
            } else {
                $("label[for=embed-popup]").hide();
            }
        });
        $("#embed-stop").on('change', function() {
            if ($(this).val()) {
                embedVars['stop'] = $(this).val();
            } else {
                delete embedVars['stop'];
            }
            updateEmbedUrl();
        });
        $("#embed-popup").on('change', function() {
            if ($(this).prop("checked")) {
                embedVars['popup'] = true;
            } else {
                delete embedVars['popup'];
            }
            updateEmbedUrl();
        });
        // After ANY field is updated...
        $("#embed-form :input").on('change', function() {
            updateEmbedCode();
        });
        // Hilight code for easy copying on click, key, focus.
        $("#embed-code").on('focus click keydown keyup', function() {
            $(this).select();
        });
        // Fire a fake change event to ensure sync between form, preview, and code.
        $("#embed-form :input").change();
    }

    init();
    return that;
}
